# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/survey/survey/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/survey/survey/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Survey\\Survey\\": "packages/survey/survey/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Survey\Survey\Providers\SurveyServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Survey'  => Survey\Survey\Facades\Survey::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Survey\\SurveyTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Survey\Survey\Providers\SurveyServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Survey\Survey\Providers\SurveyServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Survey\Survey\Providers\SurveyServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/survey/{modulename}

**User**

    http://path-to-route-folder/user/survey/{modulename}

**Public**

    http://path-to-route-folder/surveys


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/survey/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/survey/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/survey/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/survey/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/survey/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/survey/{modulename}/{slug}
    METHOD: GET