<?php

namespace Survey\Survey\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Survey\Survey\Http\Requests\AudienceRequest;
use Survey\Survey\Interfaces\AudienceRepositoryInterface;
use Survey\Survey\Models\Audience;
use Survey\Survey\Forms\Audience as Form;

/**
 * APIController  class for audience.
 */
class AudienceAPIController extends BaseController
{

    /**
     * Initialize audience resource controller.
     *
     * @param type AudienceRepositoryInterface $audience
     *
     * @return null
     */
    public function __construct(AudienceRepositoryInterface $audience)
    {
        parent::__construct();
        $this->repository = $audience;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Survey\Repositories\Criteria\AudienceResourceCriteria::class);
    }

    /**
     * Display a list of audience.
     *
     * @return Response
     */
    public function index(AudienceRequest $request)
    {
        return $this->repository
            ->setPresenter(\Survey\Survey\Repositories\Presenter\AudiencePresenter::class)
            ->paginate();
    }

    /**
     * Display audience.
     *
     * @param Request $request
     * @param Model   $audience
     *
     * @return Response
     */
    public function show(AudienceRequest $request, Audience $audience)
    {
        return $audience->setPresenter(\Survey\Survey\Repositories\Presenter\AudienceListPresenter::class);
        ;
    }

    /**
     * Create new audience.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AudienceRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('survey::audience.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('survey/audience/' . $audience->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/audience');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the audience.
     *
     * @param Request $request
     * @param Model   $audience
     *
     * @return Response
     */
    public function update(AudienceRequest $request, Audience $audience)
    {
        try {
            $data = $request->all();

            $audience->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('survey::audience.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('survey/audience/' . $audience->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/audience/' . $audience->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the audience.
     *
     * @param Model   $audience
     *
     * @return Response
     */
    public function destroy(AudienceRequest $request, Audience $audience)
    {
        try {
            $audience->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('survey::audience.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('survey/audience/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/audience/' . $audience->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
