<?php

namespace Survey\Survey\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Survey\Survey\Http\Requests\SurveyRequest;
use Survey\Survey\Interfaces\SurveyRepositoryInterface;
use Survey\Survey\Models\Survey;
use Survey\Survey\Forms\Survey as Form;

/**
 * APIController  class for survey.
 */
class SurveyAPIController extends BaseController
{

    /**
     * Initialize survey resource controller.
     *
     * @param type SurveyRepositoryInterface $survey
     *
     * @return null
     */
    public function __construct(SurveyRepositoryInterface $survey)
    {
        parent::__construct();
        $this->repository = $survey;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Survey\Repositories\Criteria\SurveyResourceCriteria::class);
    }

    /**
     * Display a list of survey.
     *
     * @return Response
     */
    public function index(SurveyRequest $request)
    {
        return $this->repository
            ->setPresenter(\Survey\Survey\Repositories\Presenter\SurveyPresenter::class)
            ->paginate();
    }

    /**
     * Display survey.
     *
     * @param Request $request
     * @param Model   $survey
     *
     * @return Response
     */
    public function show(SurveyRequest $request, Survey $survey)
    {
        return $survey->setPresenter(\Survey\Survey\Repositories\Presenter\SurveyListPresenter::class);
        ;
    }

    /**
     * Create new survey.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SurveyRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('survey::survey.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('survey/survey/' . $survey->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/survey');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the survey.
     *
     * @param Request $request
     * @param Model   $survey
     *
     * @return Response
     */
    public function update(SurveyRequest $request, Survey $survey)
    {
        try {
            $data = $request->all();

            $survey->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('survey::survey.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('survey/survey/' . $survey->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/survey/' . $survey->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the survey.
     *
     * @param Model   $survey
     *
     * @return Response
     */
    public function destroy(SurveyRequest $request, Survey $survey)
    {
        try {
            $survey->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('survey::survey.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('survey/survey/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/survey/' . $survey->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
