<?php

namespace Survey\Survey\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Survey\Survey\Http\Requests\ThemeRequest;
use Survey\Survey\Interfaces\ThemeRepositoryInterface;
use Survey\Survey\Models\Theme;
use Survey\Survey\Forms\Theme as Form;

/**
 * APIController  class for theme.
 */
class ThemeAPIController extends BaseController
{

    /**
     * Initialize theme resource controller.
     *
     * @param type ThemeRepositoryInterface $theme
     *
     * @return null
     */
    public function __construct(ThemeRepositoryInterface $theme)
    {
        parent::__construct();
        $this->repository = $theme;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Survey\Repositories\Criteria\ThemeResourceCriteria::class);
    }

    /**
     * Display a list of theme.
     *
     * @return Response
     */
    public function index(ThemeRequest $request)
    {
        return $this->repository
            ->setPresenter(\Survey\Survey\Repositories\Presenter\ThemePresenter::class)
            ->paginate();
    }

    /**
     * Display theme.
     *
     * @param Request $request
     * @param Model   $theme
     *
     * @return Response
     */
    public function show(ThemeRequest $request, Theme $theme)
    {
        return $theme->setPresenter(\Survey\Survey\Repositories\Presenter\ThemeListPresenter::class);
        ;
    }

    /**
     * Create new theme.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ThemeRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('survey::theme.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('survey/theme/' . $theme->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/theme');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the theme.
     *
     * @param Request $request
     * @param Model   $theme
     *
     * @return Response
     */
    public function update(ThemeRequest $request, Theme $theme)
    {
        try {
            $data = $request->all();

            $theme->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('survey::theme.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('survey/theme/' . $theme->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/theme/' . $theme->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the theme.
     *
     * @param Model   $theme
     *
     * @return Response
     */
    public function destroy(ThemeRequest $request, Theme $theme)
    {
        try {
            $theme->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('survey::theme.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('survey/theme/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('survey/theme/' . $theme->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
