<?php

namespace Survey\Survey\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Survey\Models\Audience;

class AudiencePolicy
{

    /**
     * Determine if the given user can view the audience.
     *
     * @param UserPolicy $user
     * @param Audience $audience
     *
     * @return bool
     */
    public function view(UserPolicy $user, Audience $audience)
    {
        if ($user->canDo('survey.audience.view') && $user->isAdmin()) {
            return true;
        }

        return $audience->user_id == user_id() && $audience->user_type == user_type();
    }

    /**
     * Determine if the given user can create a audience.
     *
     * @param UserPolicy $user
     * @param Audience $audience
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('survey.audience.create');
    }

    /**
     * Determine if the given user can update the given audience.
     *
     * @param UserPolicy $user
     * @param Audience $audience
     *
     * @return bool
     */
    public function update(UserPolicy $user, Audience $audience)
    {
        if ($user->canDo('survey.audience.edit') && $user->isAdmin()) {
            return true;
        }

        return $audience->user_id == user_id() && $audience->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given audience.
     *
     * @param UserPolicy $user
     * @param Audience $audience
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Audience $audience)
    {
        return $audience->user_id == user_id() && $audience->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given audience.
     *
     * @param UserPolicy $user
     * @param Audience $audience
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Audience $audience)
    {
        if ($user->canDo('survey.audience.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given audience.
     *
     * @param UserPolicy $user
     * @param Audience $audience
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Audience $audience)
    {
        if ($user->canDo('survey.audience.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
