<?php

namespace Survey\Survey\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Survey\Models\Distribution;

class DistributionPolicy
{

    /**
     * Determine if the given user can view the distribution.
     *
     * @param UserPolicy $user
     * @param Distribution $distribution
     *
     * @return bool
     */
    public function view(UserPolicy $user, Distribution $distribution)
    {
        if ($user->canDo('survey.distribution.view') && $user->isAdmin()) {
            return true;
        }

        return $distribution->user_id == user_id() && $distribution->user_type == user_type();
    }

    /**
     * Determine if the given user can create a distribution.
     *
     * @param UserPolicy $user
     * @param Distribution $distribution
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('survey.distribution.create');
    }

    /**
     * Determine if the given user can update the given distribution.
     *
     * @param UserPolicy $user
     * @param Distribution $distribution
     *
     * @return bool
     */
    public function update(UserPolicy $user, Distribution $distribution)
    {
        if ($user->canDo('survey.distribution.edit') && $user->isAdmin()) {
            return true;
        }

        return $distribution->user_id == user_id() && $distribution->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given distribution.
     *
     * @param UserPolicy $user
     * @param Distribution $distribution
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Distribution $distribution)
    {
        return $distribution->user_id == user_id() && $distribution->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given distribution.
     *
     * @param UserPolicy $user
     * @param Distribution $distribution
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Distribution $distribution)
    {
        if ($user->canDo('survey.distribution.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given distribution.
     *
     * @param UserPolicy $user
     * @param Distribution $distribution
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Distribution $distribution)
    {
        if ($user->canDo('survey.distribution.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
