<?php

namespace Survey\Survey\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Survey\Models\Notific;

class NotificPolicy
{

    /**
     * Determine if the given user can view the notific.
     *
     * @param UserPolicy $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function view(UserPolicy $user, Notific $notific)
    {
        if ($user->canDo('survey.notific.view') && $user->isAdmin()) {
            return true;
        }

        return $notific->user_id == user_id() && $notific->user_type == user_type();
    }

    /**
     * Determine if the given user can create a notific.
     *
     * @param UserPolicy $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('survey.notific.create');
    }

    /**
     * Determine if the given user can update the given notific.
     *
     * @param UserPolicy $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function update(UserPolicy $user, Notific $notific)
    {
        if ($user->canDo('survey.notific.edit') && $user->isAdmin()) {
            return true;
        }

        return $notific->user_id == user_id() && $notific->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given notific.
     *
     * @param UserPolicy $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Notific $notific)
    {
        return $notific->user_id == user_id() && $notific->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given notific.
     *
     * @param UserPolicy $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Notific $notific)
    {
        if ($user->canDo('survey.notific.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given notific.
     *
     * @param UserPolicy $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Notific $notific)
    {
        if ($user->canDo('survey.notific.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
