<?php

namespace Survey\Survey\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Survey\Models\Reminder;

class ReminderPolicy
{

    /**
     * Determine if the given user can view the reminder.
     *
     * @param UserPolicy $user
     * @param Reminder $reminder
     *
     * @return bool
     */
    public function view(UserPolicy $user, Reminder $reminder)
    {
        if ($user->canDo('survey.reminder.view') && $user->isAdmin()) {
            return true;
        }

        return $reminder->user_id == user_id() && $reminder->user_type == user_type();
    }

    /**
     * Determine if the given user can create a reminder.
     *
     * @param UserPolicy $user
     * @param Reminder $reminder
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('survey.reminder.create');
    }

    /**
     * Determine if the given user can update the given reminder.
     *
     * @param UserPolicy $user
     * @param Reminder $reminder
     *
     * @return bool
     */
    public function update(UserPolicy $user, Reminder $reminder)
    {
        if ($user->canDo('survey.reminder.edit') && $user->isAdmin()) {
            return true;
        }

        return $reminder->user_id == user_id() && $reminder->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given reminder.
     *
     * @param UserPolicy $user
     * @param Reminder $reminder
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Reminder $reminder)
    {
        return $reminder->user_id == user_id() && $reminder->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given reminder.
     *
     * @param UserPolicy $user
     * @param Reminder $reminder
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Reminder $reminder)
    {
        if ($user->canDo('survey.reminder.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given reminder.
     *
     * @param UserPolicy $user
     * @param Reminder $reminder
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Reminder $reminder)
    {
        if ($user->canDo('survey.reminder.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
