<?php

namespace Survey\Survey\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Survey\Models\Reporting;

class ReportingPolicy
{

    /**
     * Determine if the given user can view the reporting.
     *
     * @param UserPolicy $user
     * @param Reporting $reporting
     *
     * @return bool
     */
    public function view(UserPolicy $user, Reporting $reporting)
    {
        if ($user->canDo('survey.reporting.view') && $user->isAdmin()) {
            return true;
        }

        return $reporting->user_id == user_id() && $reporting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a reporting.
     *
     * @param UserPolicy $user
     * @param Reporting $reporting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('survey.reporting.create');
    }

    /**
     * Determine if the given user can update the given reporting.
     *
     * @param UserPolicy $user
     * @param Reporting $reporting
     *
     * @return bool
     */
    public function update(UserPolicy $user, Reporting $reporting)
    {
        if ($user->canDo('survey.reporting.edit') && $user->isAdmin()) {
            return true;
        }

        return $reporting->user_id == user_id() && $reporting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given reporting.
     *
     * @param UserPolicy $user
     * @param Reporting $reporting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Reporting $reporting)
    {
        return $reporting->user_id == user_id() && $reporting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given reporting.
     *
     * @param UserPolicy $user
     * @param Reporting $reporting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Reporting $reporting)
    {
        if ($user->canDo('survey.reporting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given reporting.
     *
     * @param UserPolicy $user
     * @param Reporting $reporting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Reporting $reporting)
    {
        if ($user->canDo('survey.reporting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
