<?php

namespace Survey\Survey\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Survey\Models\Theme;

class ThemePolicy
{

    /**
     * Determine if the given user can view the theme.
     *
     * @param UserPolicy $user
     * @param Theme $theme
     *
     * @return bool
     */
    public function view(UserPolicy $user, Theme $theme)
    {
        if ($user->canDo('survey.theme.view') && $user->isAdmin()) {
            return true;
        }

        return $theme->user_id == user_id() && $theme->user_type == user_type();
    }

    /**
     * Determine if the given user can create a theme.
     *
     * @param UserPolicy $user
     * @param Theme $theme
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('survey.theme.create');
    }

    /**
     * Determine if the given user can update the given theme.
     *
     * @param UserPolicy $user
     * @param Theme $theme
     *
     * @return bool
     */
    public function update(UserPolicy $user, Theme $theme)
    {
        if ($user->canDo('survey.theme.edit') && $user->isAdmin()) {
            return true;
        }

        return $theme->user_id == user_id() && $theme->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given theme.
     *
     * @param UserPolicy $user
     * @param Theme $theme
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Theme $theme)
    {
        return $theme->user_id == user_id() && $theme->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given theme.
     *
     * @param UserPolicy $user
     * @param Theme $theme
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Theme $theme)
    {
        if ($user->canDo('survey.theme.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given theme.
     *
     * @param UserPolicy $user
     * @param Theme $theme
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Theme $theme)
    {
        if ($user->canDo('survey.theme.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
