<?php

namespace Survey\Survey\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Survey\Survey\Models\Survey;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Survey\Survey\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/survey/survey/*')) {
            Route::bind('survey', function ($survey) {
                $surveyrepo = $this->app->make('Survey\Survey\Interfaces\SurveyRepositoryInterface');
                return $surveyrepo->findorNew($survey);
            });
        }

        if (Request::is('*/survey/audience/*')) {
            Route::bind('audience', function ($audience) {
                $audiencerepo = $this->app->make('Survey\Survey\Interfaces\AudienceRepositoryInterface');
                return $audiencerepo->findorNew($audience);
            });
        }

        if (Request::is('*/survey/distribution/*')) {
            Route::bind('distribution', function ($distribution) {
                $distributionrepo = $this->app->make('Survey\Survey\Interfaces\DistributionRepositoryInterface');
                return $distributionrepo->findorNew($distribution);
            });
        }

        if (Request::is('*/survey/reminder/*')) {
            Route::bind('reminder', function ($reminder) {
                $reminderrepo = $this->app->make('Survey\Survey\Interfaces\ReminderRepositoryInterface');
                return $reminderrepo->findorNew($reminder);
            });
        }

        if (Request::is('*/survey/reporting/*')) {
            Route::bind('reporting', function ($reporting) {
                $reportingrepo = $this->app->make('Survey\Survey\Interfaces\ReportingRepositoryInterface');
                return $reportingrepo->findorNew($reporting);
            });
        }

        if (Request::is('*/survey/theme/*')) {
            Route::bind('theme', function ($theme) {
                $themerepo = $this->app->make('Survey\Survey\Interfaces\ThemeRepositoryInterface');
                return $themerepo->findorNew($theme);
            });
        }

        if (Request::is('*/survey/notific/*')) {
            Route::bind('notific', function ($notific) {
                $notificrepo = $this->app->make('Survey\Survey\Interfaces\NotificRepositoryInterface');
                return $notificrepo->findorNew($notific);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
